#
# spec file for package perl-Mojo-Redis
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mojo-Redis
Name:           perl-Mojo-Redis
Version:        3.29
Release:        1.13
License:        Artistic-2.0
Summary:        Redis driver based on Mojo::IOLoop
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JH/JHTHORSEN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Mojolicious) >= 8.50
BuildRequires:  perl(Protocol::Redis::Faster) >= 0.002
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(Mojolicious) >= 8.50
Requires:       perl(Protocol::Redis::Faster) >= 0.002
%{perl_requires}

%description
Mojo::Redis is a Redis driver that use the Mojo::IOLoop, which makes it
integrate easily with the Mojolicious framework.

It tries to mimic the same interface as Mojo::Pg, Mojo::mysql and
Mojo::SQLite, but the methods for talking to the database vary.

This module is in no way compatible with the 1.xx version of 'Mojo::Redis'
and this version also tries to fix a lot of the confusing methods in
'Mojo::Redis2' related to pubsub.

This module is currently EXPERIMENTAL, and bad design decisions will be
fixed without warning. Please report at
https://github.com/jhthorsen/mojo-redis/issues if you find this module
useful, annoying or if you simply find bugs. Feedback can also be sent to
'jhthorsen@cpan.org'.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md

%changelog
* Thu Feb 24 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.29
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.29 2022-02-23T14:56:18+0900
  - Fix use of "defined" in unit test
  3.28 2022-02-21T15:40:56+0900
  - Add channel to Mojo::Redis::PubSub::listen() callback
* Sat Nov 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.27
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.27 2021-11-20T10:51:49+0900
  - Add experimental "subscribe" and "psubscribe" events to Mojo::Redis::PubSub
  - Fix examples for set and expire #62
  - Fix handling "psubscribe" response from Redis #63
  - Fix sending database requests after connecting to sentinel server #64
  - Fix only passing on (p)message messages to listen handlers #67
  - Remove experimental write_q() method, and replaced it with write()
  - Remove the ->multi_p(@promises) syntax #68 #70
    Contributor: Jan "Yenya" Kasprzak
* Mon Mar  1 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.26
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.26 2021-03-01T09:01:51+0900
  - Avoid circular reference in redis response parser
    Contributor: Dan Book
* Sun Oct  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.25
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.25 2020-10-02T10:21:30+0900
  - Fix handling undef() in _process_...() methods #56
  - Fix some leaks in Mojo::Redis::PubSub
  - Add Mojo::Redis::PubSub->notify_p()
* Wed May  8 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.24
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.24 2019-05-07T22:25:50+0700
  - Fix PubSub->keyspace_listen() #42
* Sun May  5 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.23
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.23 2019-05-04T21:12:25+0700
  - Fix compatibility with Mojolicious 8.15 #46
* Thu Apr 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.22
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.22 2019-04-24T12:32:18+0700
  - Forgot to update protocol parser for Mojo::Redis::Cache after 3.21 #43
  - Fix broken link in Mojo::Redis::Connection #44
    Contributor: Mohammad S Anwar
* Tue Apr 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.21
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.21 2019-04-16T09:58:44+0700
  - Changed default protocol parser to Protocol::Redis::XS #43
* Thu Apr  4 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.20
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.20 2019-04-04T10:31:03+0700
  - Use Protocol::Redis::Faster instead of Protocol::Redis #38
  - Only decode data from bulk string responses #40
  - Fix allowing custom URL object with userinfo in constructor #41
* Thu Jan 31 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.19
  see /usr/share/doc/packages/perl-Mojo-Redis/Changes
  3.19 2019-01-31T13:03:11+0900
  - Add support for encoding and decoding of JSON messages in Mojo::Redis::PubSub
  3.18 2019-01-31T12:39:46+0900
  - Add reconnect logic for Mojo::Redis::PubSub #37
  - Add CAVEATS for Protocol::Redis::XS #38
  - Changed default protocol to Protocol::Redis #38
  - Updated documentation to use nicer variable names
* Tue Jan 29 2019 sriedel@suse.de
- initial version (3.17)
